# VMMonitoringItem

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cpu** | **float** |  | [optional] 
**disk_rd_bytes** | **int** |  | [optional] 
**disk_rd_iops** | **int** |  | [optional] 
**disk_wr_bytes** | **int** |  | [optional] 
**disk_wr_iops** | **int** |  | [optional] 
**memory** | **int** |  | [optional] 
**net_rx** | **int** |  | [optional] 
**net_tx** | **int** |  | [optional] 
**timestamp** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


